| mzip | R Documentation |
Function to estimate a marginalized zero-inflated Poisson model
mzip(formula, data)
formula |
an object of class " |
data |
a data frame containing variables in the model. |
Function returns an object of class "mle2" from bbmle R package. Apply summary function to the resulting object from the function to obtain more estimation information.
Suffix _zero corresponds to the parameters associated with the structrual zero rate part of a model.
Suffix _mean corresponds to the parameters associated with the overall mean, which evaluate the effects of covariates on the overall mean.
Long, D. L., Preisser, J. S., Herring, A. H., & Golin, C. E. (2014). A marginalized zero‐inflated Poisson regression model with overall exposure effects. Statistics in Medicine, 33(29), 5151-5165.
head(dat.pfi) #Fit a marginalized zero-inflated Poisson model res = mzip(formula = y ~ m0 + int_PF + year_new + race_new, data = dat.pfi) #Obtain estimation results bbmle::summary(res)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.